@@ -3,17 +3,16 @@
 # sys.path.append("C:\\Users\\hanne\\OneDrive\\Documents\\repos\\plugget")
 import site
 site.addsitedir("C:\\Users\\hanne\\OneDrive\\Documents\\repos\\plugget")
-site.addsitedir("C:\\Users\\hanne\\OneDrive\\Documents\\repos\\plugget")
+site.addsitedir("C:\\Users\\hanne\\OneDrive\\Documents\\repos\\detect-app")
 
 import plugget
 import plugget.commands as cmd
 import plugget.data as da
 import plugget.actions.blender_addon as ba
-import plugget.apps.blender as b
 
 from importlib import reload
 reload(plugget)
-reload(b)
+# reload(b)
 reload(cmd)
 reload(da)
 reload(ba)
@@ -36,8 +35,7 @@ site.addsitedir("C:\\Users\\hanne\\OneDrive\\Documents\\repos\\plugget")
 import plugget
 import plugget.data as d
 import plugget.commands as cmd
-import plugget.actions.max_macroscript as ma
-# import plugget.apps.blender as b
+import plugget.actions.max3ds_macroscript as ma
 
 from importlib import reload
 
